@@ -234,7 +234,7 @@ class Frame(object):
                     partial = self.sock.recv(1)
                 except socket.error, exc:
                     if exc.errno == EAGAIN:
-                        if not buffer:
+                        if not buffer or buffer == '\n':
                             return None
                         continue
                 buffer += partial
